########################################################################
#updateTM_TCResults3.pl
#
# This script populates the aggregate tables with test case results.
#
########################################################################

use PjCLib;
use Win32::OLE;
require CQPerlExt;


################
# main
################

# Global variables
$currentDate; # SQL date format
$currentTime; # SQL time format

# Initialize the date/time variables.
getCurrentDateTime();

# Get the ProjectConsole CQ session variable.
$session = logon();

myMain();
exit;

sub myMain {

    # You must always call the initializePjCLibrary() first before
    # you can use the PjCLib.
    PjCLib->initializePjCLibrary($session, PjCLib->BOOLEAN_TRUE);

    ######################################################################

    # Set the names of the physical tables.

    setTableAndFieldNames();		  				# Initialize variables for the names of the physical tables & fields.

    insertRecordsIntoAggregateBuildTable();       			# Insert new totals into the build table.

    insertRecordsIntoAggregateLogTable();  				# Insert new totals into the logs & builds table.

    insertRecordsIntoAggregateIterationTable();

    insertRecordsIntoAggregateIterationAndBuildTable();

    ######################################################################
} # end subroutine myMain()

sub insertRecordsIntoAggregateIterationTable () {

    # Declare local variables used by subroutine.

    my($queryStr);               # String used to query the CQ database
    my($resultSetForTC);     	 # Results from executing a SQL query of the $TC_RESULTS_MEASURE_TABLE
    my($iterationName);          # Name of the iteration
    my($iterationUID);           # UID of the iteration
    my($projectName);            # Name of the project
    my($totalExecuted);          # Number of times test cases were executed for a build
    my($totalPassed);            # Number of times test cases passed for a build
    my($totalStopped);           # Number of times test cases were stopped for a build
    my($totalFailed);            # Number of times test cases failed for a build
    my($totalUnevaluated);       # Number of times test cases were unevaluated for a build
    my($totalWarning);           # Number of times test cases had warnings for a build
    my($totalInformational);     # Number of times test cases had a status of "Informational" for a build
    my($totalTC);                # Total number of test cases for a build
    my($entity);                 # Record to add to $tableName
    my($retval);                 # Return value after adding record to $tableName

    # Create a SQL statement that totals up the number of passes, failures, warnings... for each iteration.

    $queryStr = "SELECT $ITERATIONNAME_DIM_TABLE.$TM_ITERATION_NAME, $ITERATIONUID_DIM_TABLE.$TM_ITERATION_UID, " .
                "$PROJECTNAME_DIM_TABLE.$TM_PROJECT_NAME, SUM($TOTAL_EXECUTED) AS TotalExecuted, " .
                "SUM($TOTAL_PASSED) AS TotalPass, SUM($TOTAL_STOPPED) AS TotalStopped, " .
	        "SUM($TOTAL_FAILED) AS TotalFailed, SUM($TOTAL_UNEVALUATED) AS TotalUnevaluated, " .
		"SUM($TOTAL_WARNING) AS TotalWarning, SUM($TOTAL_INFORMATIONAL) AS TotalInformational, " .
		"COUNT($INTERPRETED_RESULT) AS TotalTC " .
                "FROM $TC_RESULTS_MEASURE_TABLE INNER JOIN $ITERATIONNAME_DIM_TABLE ON " .
                "$TC_RESULTS_MEASURE_TABLE.$ITERATION_NAME = $ITERATIONNAME_DIM_TABLE.dbid INNER JOIN " .
                "$ITERATIONUID_DIM_TABLE ON $TC_RESULTS_MEASURE_TABLE.$ITERATION_UID = $ITERATIONUID_DIM_TABLE.dbid " .
                "INNER JOIN $PROJECTNAME_DIM_TABLE ON $TC_RESULTS_MEASURE_TABLE.$PROJECT = $PROJECTNAME_DIM_TABLE.dbid ".
                "WHERE ($INTERPRETED_RESULT  <> 0 AND $LATEST_COLLECTION = 1) " .
                "GROUP BY $ITERATIONNAME_DIM_TABLE.$TM_ITERATION_NAME, $ITERATIONUID_DIM_TABLE.$TM_ITERATION_UID, " .
                "$PROJECTNAME_DIM_TABLE.$TM_PROJECT_NAME";

    print "queryStr for totaling passes, failures... for iteration = \n";
    print "$queryStr\n";

    # Execute the query that totals up the number of passes, failures, warnings... for each iteration.

    $resultSetForTC = $session->BuildSQLQuery($queryStr);
    $resultSetForTC->Execute();

    while ($resultSetForTC->MoveNext() == $CQPerlExt::CQ_SUCCESS) {

	# Extract the name of the iteration, project, & the total values associated with it from the current record.
	
        $iterationName = $resultSetForTC->GetColumnValue(1);
        $iterationUID = $resultSetForTC->GetColumnValue(2);
        $projectName = $resultSetForTC->GetColumnValue(3);
 	$totalExecuted = $resultSetForTC->GetColumnValue(4);
        $totalPassed = $resultSetForTC->GetColumnValue(5);
        $totalStopped = $resultSetForTC->GetColumnValue(6);
        $totalFailed = $resultSetForTC->GetColumnValue(7);
        $totalUnevaluated = $resultSetForTC->GetColumnValue(8);
        $totalWarning = $resultSetForTC->GetColumnValue(9);
        $totalInformational = $resultSetForTC->GetColumnValue(10);
        $totalTC = $resultSetForTC->GetColumnValue(11);
        print "iterationName: $iterationName\n";
        print "iterationUID: $iterationUID\n";
        print "projectName: $projectName\n";
	print "totalExecuted: $totalExecuted\n";
	print "totalPassed: $totalPassed\n";
	print "totalStopped: $totalStopped\n";
	print "totalFailed: $totalFailed\n";
	print "totalUnevaluated: $totalUnevaluated\n";
	print "totalWarning: $totalWarning\n";
	print "totalInformational: $totalInformational\n";
	print "totalTC: $totalTC\n";

	# Create a new CQ record in the $tableName. Insert the name of the iteration and the total
	# values associated with the iteration.

        $entity = $session->BuildEntity("$TOTALS_BY_ITERATION_TABLE");
        $entity->SetFieldValue("$ITERATION_NAME_FOR_ITERATION", $iterationName);
        $entity->SetFieldValue("$ITERATION_UID_FOR_ITERATION", $iterationUID);
        $entity->SetFieldValue("$PROJECT_FOR_ITERATION", $projectName);
        $entity->SetFieldValue("$LATEST_COLLECTION_FOR_ITERATION", "1");
        $entity->SetFieldValue("$TOTAL_EXECUTED_BY_ITERATION", $totalExecuted);
        $entity->SetFieldValue("$TOTAL_PASSED_BY_ITERATION", $totalPassed);
        $entity->SetFieldValue("$TOTAL_STOPPED_BY_ITERATION", $totalStopped);
        $entity->SetFieldValue("$TOTAL_FAILED_BY_ITERATION", $totalFailed);
        $entity->SetFieldValue("$TOTAL_UNEVALUATED_BY_ITERATION", $totalUnevaluated);
        $entity->SetFieldValue("$TOTAL_WARNING_BY_ITERATION", $totalWarning);
        $entity->SetFieldValue("$TOTAL_INFORMATIONAL_BY_ITERATION", $totalInformational);
        $entity->SetFieldValue("$TOTAL_TC_BY_ITERATION", $totalTC);
        $retVal = $entity->Validate();
        print "iteration table entity->Validate() return value = $retVal\n";
        $retVal = $entity->Commit();
        print "iteration table entity->Commit() return value = $retVal\n";
    }
} # end subroutine insertRecordsIntoAggregateIterationTable


sub insertRecordsIntoAggregateIterationAndBuildTable () {

    # Declare local variables used by subroutine.

    my($queryStr);               # String used to query the CQ database
    my($resultSetForTC);     	 # Results from executing a SQL query of the $TC_RESULTS_MEASURE_TABLE
    my($resultSetForIteration);  # Results from executing a SQL query of the $ITERATIONNAME_DIM_TABLE
    my($resultSetForBuild);      # Results from executing a SQL query of the $BUILDNAME_DIM_TABLE
    my($iterationName);          # Name of the iteration
    my($iterationUID);           # UID of the iteration
    my($buildName);          	 # Name of the build
    my($buildUID);               # UID of the build
    my($projectName);            # Name of the project
    my($totalExecuted);          # Number of times test cases were executed for a build
    my($totalPassed);            # Number of times test cases passed for a build
    my($totalStopped);           # Number of times test cases were stopped for a build
    my($totalFailed);            # Number of times test cases failed for a build
    my($totalUnevaluated);       # Number of times test cases were unevaluated for a build
    my($totalWarning);           # Number of times test cases had warnings for a build
    my($totalInformational);     # Number of times test cases had a status of "Informational" for a build
    my($totalTC);                # Total number of test cases for a build
    my($entity);                 # Record to add to $tableName
    my($retval);                 # Return value after adding record to $tableName

    # Create a SQL statement that totals up the number of passes, failures, warnings... for each 
    # iteration and build.

    $queryStr = "SELECT $ITERATIONNAME_DIM_TABLE.$TM_ITERATION_NAME, $ITERATIONUID_DIM_TABLE.$TM_ITERATION_UID, " .
                "$PROJECTNAME_DIM_TABLE.$TM_PROJECT_NAME, $BUILDNAME_DIM_TABLE.$TM_BUILD_NAME, " .
                "$BUILDUID_DIM_TABLE.$TM_BUILD_UID, SUM($TOTAL_EXECUTED) AS TotalExecuted, " .
                "SUM($TOTAL_PASSED) AS TotalPass, SUM($TOTAL_STOPPED) AS TotalStopped, " .
	        "SUM($TOTAL_FAILED) AS TotalFailed, SUM($TOTAL_UNEVALUATED) AS TotalUnevaluated, " .
		"SUM($TOTAL_WARNING) AS TotalWarning, SUM($TOTAL_INFORMATIONAL) AS TotalInformational, " .
		"COUNT($INTERPRETED_RESULT) AS TotalTC " .
                "FROM $TC_RESULTS_MEASURE_TABLE INNER JOIN $ITERATIONNAME_DIM_TABLE ON " .
                "$TC_RESULTS_MEASURE_TABLE.$ITERATION_NAME = $ITERATIONNAME_DIM_TABLE.dbid INNER JOIN " .
                "$ITERATIONUID_DIM_TABLE ON $TC_RESULTS_MEASURE_TABLE.$ITERATION_UID = $ITERATIONUID_DIM_TABLE.dbid " .
                "INNER JOIN $PROJECTNAME_DIM_TABLE ON $TC_RESULTS_MEASURE_TABLE.$PROJECT = $PROJECTNAME_DIM_TABLE.dbid ".
                "INNER JOIN $BUILDNAME_DIM_TABLE ON $TC_RESULTS_MEASURE_TABLE.$BUILD_NAME = $BUILDNAME_DIM_TABLE.dbid " .
                "INNER JOIN $BUILDUID_DIM_TABLE ON $TC_RESULTS_MEASURE_TABLE.$BUILD_UID = $BUILDUID_DIM_TABLE.dbid " .
                "WHERE ($INTERPRETED_RESULT  <> 0 AND $LATEST_COLLECTION = 1) " .
                "GROUP BY $ITERATIONNAME_DIM_TABLE.$TM_ITERATION_NAME, $ITERATIONUID_DIM_TABLE.$TM_ITERATION_UID, " .
                "$PROJECTNAME_DIM_TABLE.$TM_PROJECT_NAME, $BUILDNAME_DIM_TABLE.$TM_BUILD_NAME, $BUILDUID_DIM_TABLE.$TM_BUILD_UID";


    print "queryStr for totaling passes, failures... for iteration & build = \n";
    print "$queryStr\n";

    # Execute the query that totals up the number of passes, failures, warnings... for each iteration and build.

    $resultSetForTC = $session->BuildSQLQuery($queryStr);
    $resultSetForTC->Execute();

    while ($resultSetForTC->MoveNext() == $CQPerlExt::CQ_SUCCESS) {

	# Extract the name of the iteration, name of the build & the total values associated with it from the current record.
	
        $iterationName = $resultSetForTC->GetColumnValue(1);
        $iterationUID = $resultSetForTC->GetColumnValue(2);
        $projectName = $resultSetForTC->GetColumnValue(3);
        $buildName = $resultSetForTC->GetColumnValue(4);
        $buildUID = $resultSetForTC->GetColumnValue(5);
 	$totalExecuted = $resultSetForTC->GetColumnValue(6);
        $totalPassed = $resultSetForTC->GetColumnValue(7);
        $totalStopped = $resultSetForTC->GetColumnValue(8);
        $totalFailed = $resultSetForTC->GetColumnValue(9);
        $totalUnevaluated = $resultSetForTC->GetColumnValue(10);
        $totalWarning = $resultSetForTC->GetColumnValue(11);
        $totalInformational = $resultSetForTC->GetColumnValue(12);
        $totalTC = $resultSetForTC->GetColumnValue(13);
        print "iterationName: $iterationName\n";
        print "iterationUID: $iterationUID\n";
        print "buildName: $buildName\n";
        print "buildUID: $buildUID\n";
        print "projectName: $projectName\n";
	print "totalExecuted: $totalExecuted\n";
	print "totalPassed: $totalPassed\n";
	print "totalStopped: $totalStopped\n";
	print "totalFailed: $totalFailed\n";
	print "totalUnevaluated: $totalUnevaluated\n";
	print "totalWarning: $totalWarning\n";
	print "totalInformational: $totalInformational\n";
	print "totalTC: $totalTC\n";

	# Create a new CQ record in the $tableName. Insert the name of the iteration, name of the
        # build, and the total values associated with the iteration.

        $entity = $session->BuildEntity("$TOTALS_BY_ITERATION_AND_BUILD_TABLE");
        $entity->SetFieldValue("$ITERATION_NAME_FOR_ITERATION_AND_BUILD", $iterationName);
        $entity->SetFieldValue("$ITERATION_UID_FOR_ITERATION_AND_BUILD", $iterationUID);
        $entity->SetFieldValue("$BUILD_NAME_FOR_ITERATION_AND_BUILD", $buildName);
        $entity->SetFieldValue("$BUILD_UID_FOR_ITERATION_AND_BUILD", $buildUID);
        $entity->SetFieldValue("$PROJECT_FOR_ITERATION_AND_BUILD", $projectName);
        $entity->SetFieldValue("$LATEST_COLLECTION_FOR_ITERATION_AND_BUILD", "1");
        $entity->SetFieldValue("$TOTAL_EXECUTED_BY_ITERATION_AND_BUILD", $totalExecuted);
        $entity->SetFieldValue("$TOTAL_PASSED_BY_ITERATION_AND_BUILD", $totalPassed);
        $entity->SetFieldValue("$TOTAL_STOPPED_BY_ITERATION_AND_BUILD", $totalStopped);
        $entity->SetFieldValue("$TOTAL_FAILED_BY_ITERATION_AND_BUILD", $totalFailed);
        $entity->SetFieldValue("$TOTAL_UNEVALUATED_BY_ITERATION_AND_BUILD", $totalUnevaluated);
        $entity->SetFieldValue("$TOTAL_WARNING_BY_ITERATION_AND_BUILD", $totalWarning);
        $entity->SetFieldValue("$TOTAL_INFORMATIONAL_BY_ITERATION_AND_BUILD", $totalInformational);
        $entity->SetFieldValue("$TOTAL_TC_BY_ITERATION_AND_BUILD", $totalTC);
        $retVal = $entity->Validate();
        print "iteration & build table entity->Validate() return value = $retVal\n";
        $retVal = $entity->Commit();
        print "iteration & build table entity->Commit() return value = $retVal\n";
    }
} # end subroutine insertRecordsIntoAggregateIterationAndBuildTable


sub insertRecordsIntoAggregateBuildTable () {

    # Declare local variables used by subroutine.

    my($queryStr);           # String used to query the CQ database
    my($resultSetForTC);     # Results from executing a SQL query of the $TC_RESULTS_MEASURE_TABLE
    my($buildUID);           # UID of the build
    my($buildName);          # Name of the build 
    my($projectName);        # Name of the project
    my($totalExecuted);      # Number of times test cases were executed for a build
    my($totalPassed);        # Number of times test cases passed for a build
    my($totalStopped);       # Number of times test cases were stopped for a build
    my($totalFailed);        # Number of times test cases failed for a build
    my($totalUnevaluated);   # Number of times test cases were unevaluated for a build
    my($totalWarning);       # Number of times test cases had warnings for a build
    my($totalInformational); # Number of times test cases had a status of "Informational" for a build
    my($totalTC);            # Total number of test cases for a build
    my($entity);             # Record to add to $tableName
    my($retval);             # Return value after adding record to $tableName

    # Create a SQL statement that totals up the number of passes, failures, warnings... for each build.

    $queryStr = "SELECT $BUILDNAME_DIM_TABLE.$TM_BUILD_NAME, $BUILDUID_DIM_TABLE.$TM_BUILD_UID, " .
                "$PROJECTNAME_DIM_TABLE.$TM_PROJECT_NAME, SUM($TOTAL_EXECUTED) AS TotalExecuted, " .
                "SUM($TOTAL_PASSED) AS TotalPass, SUM($TOTAL_STOPPED) AS TotalStopped, " .
	        "SUM($TOTAL_FAILED) AS TotalFailed, SUM($TOTAL_UNEVALUATED) AS TotalUnevaluated, " .
		"SUM($TOTAL_WARNING) AS TotalWarning, SUM($TOTAL_INFORMATIONAL) AS TotalInformational, " .
		"COUNT($INTERPRETED_RESULT) AS TotalTC " .
                "FROM $TC_RESULTS_MEASURE_TABLE INNER JOIN $BUILDNAME_DIM_TABLE ON " .
                "$TC_RESULTS_MEASURE_TABLE.$BUILD_NAME = $BUILDNAME_DIM_TABLE.dbid INNER JOIN " .
                "$BUILDUID_DIM_TABLE ON $TC_RESULTS_MEASURE_TABLE.$BUILD_UID = $BUILDUID_DIM_TABLE.dbid " .
                "INNER JOIN $PROJECTNAME_DIM_TABLE ON $TC_RESULTS_MEASURE_TABLE.$PROJECT = $PROJECTNAME_DIM_TABLE.dbid ".
                "WHERE ($INTERPRETED_RESULT  <> 0 AND $LATEST_COLLECTION = 1) " .
                "GROUP BY $BUILDNAME_DIM_TABLE.$TM_BUILD_NAME, $BUILDUID_DIM_TABLE.$TM_BUILD_UID, " .
                "$PROJECTNAME_DIM_TABLE.$TM_PROJECT_NAME";

    #print "insertRecordsIntoAggregateBuildTable.queryStr for totaling passes, failures... for build = \n";
    print "$queryStr\n";

    # Execute the query that totals up the number of passes, failures, warnings... for each build.

    $resultSetForTC = $session->BuildSQLQuery($queryStr);
    $resultSetForTC->Execute();

    while ($resultSetForTC->MoveNext() == $CQPerlExt::CQ_SUCCESS) {

	# Extract the name of the build, the build UID, the project, & 
        # the total values associated with it from the current record.

        $buildName = $resultSetForTC->GetColumnValue(1);
        $buildUID = $resultSetForTC->GetColumnValue(2);
        $projectName = $resultSetForTC->GetColumnValue(3);
 	$totalExecuted = $resultSetForTC->GetColumnValue(4);
        $totalPassed = $resultSetForTC->GetColumnValue(5);
        $totalStopped = $resultSetForTC->GetColumnValue(6);
        $totalFailed = $resultSetForTC->GetColumnValue(7);
        $totalUnevaluated = $resultSetForTC->GetColumnValue(8);
        $totalWarning = $resultSetForTC->GetColumnValue(9);
        $totalInformational = $resultSetForTC->GetColumnValue(10);
        $totalTC = $resultSetForTC->GetColumnValue(11);
        print "buildName: $buildName\n";
        print "buildUID: $buildUID\n";
        print "projectName: $projectName\n";
	print "totalExecuted: $totalExecuted\n";
	print "totalPassed: $totalPassed\n";
	print "totalStopped: $totalStopped\n";
	print "totalFailed: $totalFailed\n";
	print "totalUnevaluated: $totalUnevaluated\n";
	print "totalWarning: $totalWarning\n";
	print "totalInformational: $totalInformational\n";
	print "totalTC: $totalTC\n";

	# Create a new CQ record in the $tableName. Insert the name of the build, project, and the total
	# values associated with the build.

        $entity = $session->BuildEntity("$TOTALS_BY_BUILD_TABLE");
        $entity->SetFieldValue("$BUILD_NAME_FOR_BUILD", $buildName);
        $entity->SetFieldValue("$BUILD_UID_FOR_BUILD", $buildUID);
        $entity->SetFieldValue("$PROJECT_FOR_BUILD", $projectName);
        $entity->SetFieldValue("$LATEST_COLLECTION_FOR_BUILD", "1");
        $entity->SetFieldValue("$TOTAL_EXECUTED_BY_BUILD", $totalExecuted);
        $entity->SetFieldValue("$TOTAL_PASSED_BY_BUILD", $totalPassed);
        $entity->SetFieldValue("$TOTAL_STOPPED_BY_BUILD", $totalStopped);
        $entity->SetFieldValue("$TOTAL_FAILED_BY_BUILD", $totalFailed);
        $entity->SetFieldValue("$TOTAL_UNEVALUATED_BY_BUILD", $totalUnevaluated);
        $entity->SetFieldValue("$TOTAL_WARNING_BY_BUILD", $totalWarning);
        $entity->SetFieldValue("$TOTAL_INFORMATIONAL_BY_BUILD", $totalInformational);
        $entity->SetFieldValue("$TOTAL_TC_BY_BUILD", $totalTC);
        $retVal = $entity->Validate();
        print "build table entity->Validate() return value = $retVal\n";
        $retVal = $entity->Commit();
        print "build table entity->Commit() return value = $retVal\n";
    }
} # end subroutine insertRecordsIntoAggregateBuildTable


sub insertRecordsIntoAggregateLogTable () {

    # Declare local variables used by subroutine.

    my($queryStr);           # String used to query the CQ database
    my($resultSetForTC);     # Results from executing a SQL query of the $TC_RESULTS_MEASURE_TABLE
    my($resultSetForBuild);  # Results from executing a SQL query of the $BUILDNAME_DIM_TABLE
    my($buildName);          # Name of the build 
    my($buildUID);           # UID of the build 
    my($logName);            # Name of the log
    my($logUID);             # UID of the log
    my($projectName);        # Name of the project
    my($totalExecuted);      # Number of times test cases were executed for a build
    my($totalPassed);        # Number of times test cases passed for a build
    my($totalStopped);       # Number of times test cases were stopped for a build
    my($totalFailed);        # Number of times test cases failed for a build
    my($totalUnevaluated);   # Number of times test cases were unevaluated for a build
    my($totalWarning);       # Number of times test cases had warnings for a build
    my($totalInformational); # Number of times test cases had a status of "Informational" for a build
    my($totalTC);            # Total number of test cases for a build
    my($entity);             # Record to add to $tableName
    my($retval);             # Return value after adding record to $tableName

    # Create a SQL statement that totals up the number of passes, failures, warnings... for each build.

    $queryStr = "SELECT $BUILDNAME_DIM_TABLE.$TM_BUILD_NAME, $BUILDUID_DIM_TABLE.$TM_BUILD_UID, " .
                "$PROJECTNAME_DIM_TABLE.$TM_PROJECT_NAME, $LOGNAME_DIM_TABLE.$TM_LOG_NAME, $LOGUID_DIM_TABLE.$TM_LOG_UID, " .
		"SUM($TOTAL_EXECUTED) AS TotalExecuted, " .
                "SUM($TOTAL_PASSED) AS TotalPass, SUM($TOTAL_STOPPED) AS TotalStopped, " .
	        "SUM($TOTAL_FAILED) AS TotalFailed, SUM($TOTAL_UNEVALUATED) AS TotalUnevaluated, " .
		"SUM($TOTAL_WARNING) AS TotalWarning, SUM($TOTAL_INFORMATIONAL) AS TotalInformational, " .
		"COUNT($INTERPRETED_RESULT) AS TotalTC " .
                "FROM $TC_RESULTS_MEASURE_TABLE INNER JOIN $BUILDNAME_DIM_TABLE ON " .
                "$TC_RESULTS_MEASURE_TABLE.$BUILD_NAME = $BUILDNAME_DIM_TABLE.dbid INNER JOIN " .
                "$BUILDUID_DIM_TABLE ON $TC_RESULTS_MEASURE_TABLE.$BUILD_UID = $BUILDUID_DIM_TABLE.dbid " .
                "INNER JOIN $PROJECTNAME_DIM_TABLE ON $TC_RESULTS_MEASURE_TABLE.$PROJECT = $PROJECTNAME_DIM_TABLE.dbid ".
		"INNER JOIN $LOGNAME_DIM_TABLE ON $TC_RESULTS_MEASURE_TABLE.$LOG_NAME = $LOGNAME_DIM_TABLE.dbid " .
                "INNER JOIN $LOGUID_DIM_TABLE ON $TC_RESULTS_MEASURE_TABLE.$LOG_UID = $LOGUID_DIM_TABLE.dbid " .
                "WHERE ($INTERPRETED_RESULT  <> 0 AND $LATEST_COLLECTION = 1) " .
                "GROUP BY $BUILDNAME_DIM_TABLE.$TM_BUILD_NAME, $BUILDUID_DIM_TABLE.$TM_BUILD_UID, " .
                "$PROJECTNAME_DIM_TABLE.$TM_PROJECT_NAME, $LOGNAME_DIM_TABLE.$TM_LOG_NAME, $LOGUID_DIM_TABLE.$TM_LOG_UID";

    #print "queryStr for totaling passes, failures... for build = \n";
    print "$queryStr\n";

    # Execute the query that totals up the number of passes, failures, warnings... for each build & log.

    $resultSetForTC = $session->BuildSQLQuery($queryStr);
    $resultSetForTC->Execute();

    while ($resultSetForTC->MoveNext() == $CQPerlExt::CQ_SUCCESS) {

	# Extract the name of the build, name & UID of the log, project & the total values associated with it
        # from the current record.
	
        $buildName = $resultSetForTC->GetColumnValue(1);
        $buildUID = $resultSetForTC->GetColumnValue(2);
	$projectName = $resultSetForTC->GetColumnValue(3);
        $logName = $resultSetForTC->GetColumnValue(4);
        $logUID = $resultSetForTC->GetColumnValue(5);
 	$totalExecuted = $resultSetForTC->GetColumnValue(6);
        $totalPassed = $resultSetForTC->GetColumnValue(7);
        $totalStopped = $resultSetForTC->GetColumnValue(8);
        $totalFailed = $resultSetForTC->GetColumnValue(9);
        $totalUnevaluated = $resultSetForTC->GetColumnValue(10);
        $totalWarning = $resultSetForTC->GetColumnValue(11);
        $totalInformational = $resultSetForTC->GetColumnValue(12);
        $totalTC = $resultSetForTC->GetColumnValue(13);
        print "buildName: $buildName\n";
        print "buildUID: $buildUID\n";
        print "logName: $logName\n";
        print "logUID: $logUID\n";
        print "projectName: $projectName\n";
	print "totalExecuted: $totalExecuted\n";
	print "totalPassed: $totalPassed\n";
	print "totalStopped: $totalStopped\n";
	print "totalFailed: $totalFailed\n";
	print "totalUnevaluated: $totalUnevaluated\n";
	print "totalWarning: $totalWarning\n";
	print "totalInformational: $totalInformational\n";
	print "totalTC: $totalTC\n";


	# Create a new CQ record in the $tableName. Insert the name of the build, log, and the total
	# values associated with the build and log.

        $entity = $session->BuildEntity("$TOTALS_BY_LOG_AND_BUILD_TABLE");
        $entity->SetFieldValue("$BUILD_NAME_FOR_LOG_AND_BUILD", $buildName);
        $entity->SetFieldValue("$BUILD_UID_FOR_LOG_AND_BUILD", $buildUID);
        $entity->SetFieldValue("$LOG_NAME_FOR_LOG_AND_BUILD", $logName);
        $entity->SetFieldValue("$LOG_UID_FOR_LOG_AND_BUILD", $logUID);
        $entity->SetFieldValue("$PROJECT_FOR_LOG_AND_BUILD", $projectName);
        $entity->SetFieldValue("$LATEST_COLLECTION_FOR_LOG_AND_BUILD", "1");
        $entity->SetFieldValue("$TOTAL_EXECUTED_BY_LOG_AND_BUILD", $totalExecuted);
        $entity->SetFieldValue("$TOTAL_PASSED_BY_LOG_AND_BUILD", $totalPassed);
        $entity->SetFieldValue("$TOTAL_STOPPED_BY_LOG_AND_BUILD", $totalStopped);
        $entity->SetFieldValue("$TOTAL_FAILED_BY_LOG_AND_BUILD", $totalFailed);
        $entity->SetFieldValue("$TOTAL_UNEVALUATED_BY_LOG_AND_BUILD", $totalUnevaluated);
        $entity->SetFieldValue("$TOTAL_WARNING_BY_LOG_AND_BUILD", $totalWarning);
        $entity->SetFieldValue("$TOTAL_INFORMATIONAL_BY_LOG_AND_BUILD", $totalInformational);
        $entity->SetFieldValue("$TOTAL_TC_BY_LOG_AND_BUILD", $totalTC);
        $retVal = $entity->Validate();
        print "log table entity->Validate() return value = $retVal\n";
        $retVal = $entity->Commit();
        print "log table entity->Commit() return value = $retVal\n";
    }
} # end subroutine insertRecordsIntoAggregateLogTable


sub setTableAndFieldNames () {

    # Set the names of the physical tables.

    $BUILDNAME_DIM_TABLE = PjCLib->getPhysicalTableDbName("TM_BuildName_Dim");
    $BUILDUID_DIM_TABLE = PjCLib->getPhysicalTableDbName("TM_BuildUID_Dim");
    $LOGNAME_DIM_TABLE = PjCLib->getPhysicalTableDbName("TM_LogName_Dim");
    $LOGUID_DIM_TABLE = PjCLib->getPhysicalTableDbName("TM_LogUID_Dim");
    $ITERATIONNAME_DIM_TABLE = PjCLib->getPhysicalTableDbName("TM_IterationName_Dim");
    $ITERATIONUID_DIM_TABLE = PjCLib->getPhysicalTableDbName("TM_IterationUID_Dim");
    $PROJECTNAME_DIM_TABLE = PjCLib->getPhysicalTableDbName("TM_Project_Dim");
    $TC_RESULTS_MEASURE_TABLE = PjCLib->getPhysicalTableDbName("TM_TCResults_Measure");
    $TOTALS_BY_ITERATION_TABLE = PjCLib->getPhysicalTableDbName("TM_TotalsByIteration_Aggregate");
    $TOTALS_BY_ITERATION_AND_BUILD_TABLE = PjCLib->getPhysicalTableDbName("TM_TotalsByBuildAndIteration_Aggregate");
    $TOTALS_BY_BUILD_TABLE = PjCLib->getPhysicalTableDbName("TM_TotalsByBuild_Aggregate");
    $TOTALS_BY_LOG_AND_BUILD_TABLE = PjCLib->getPhysicalTableDbName("TM_TotalsByLogAndBuild_Aggregate");
    print "COLLECTION_DIM_TABLE = $COLLECTION_DIM_TABLE\n";
    print "BUILDNAME_DIM_TABLE: $BUILDNAME_DIM_TABLE\n";
    print "BUILDUID_DIM_TABLE: $BUILDUID_DIM_TABLE\n";
    print "LOGNAME_DIM_TABLE: $LOGNAME_DIM_TABLE\n";
    print "LOGUID_DIM_TABLE: $LOGUID_DIM_TABLE\n";
    print "ITERATIONNAME_DIM_TABLE: $ITERATIONNAME_DIM_TABLE\n";
    print "ITERATIONUID_DIM_TABLE: $ITERATIONUID_DIM_TABLE\n";
    print "PROJECTNAME_DIM_TABLE: $PROJECTNAME_DIM_TABLE\n";
    print "TC_RESULTS_MEASURE_TABLE: $TC_RESULTS_MEASURE_TABLE\n";
    print "TOTALS_BY_ITERATION_TABLE: $TOTALS_BY_ITERATION_TABLE\n";
    print "TOTALS_BY_ITERATION__AND_BUILD_TABLE: $TOTALS_BY_ITERATION_AND_BUILD_TABLE\n";
    print "TOTALS_BY_BUILD_TABLE: $TOTALS_BY_BUILD_TABLE\n";
    print "TOTALS_BY_LOG_AND_BUILD_TABLE: $TOTALS_BY_LOG_AND_BUILD_TABLE\n";


    # Set the names of the physical fields for the $BUILDNAME_DIM_TABLE.

    $TM_BUILD_NAME = PjCLib->getPhysicalFieldDbName("TM_BuildName_Dim", "TM_BuildName");
    print "TM_BUILD_NAME: $TM_BUILD_NAME\n";

    # Set the names of the physical fields for the $BUILDUID_DIM_TABLE.

    $TM_BUILD_UID = PjCLib->getPhysicalFieldDbName("TM_BuildUID_Dim", "TM_BuildUID");
    print "TM_BUILD_UID: $TM_BUILD_UID\n";

    # Set the names of the physical fields for the $ITERATIONNAME_DIM_TABLE.

    $TM_ITERATION_NAME = PjCLib->getPhysicalFieldDbName("TM_IterationName_Dim", "TM_IterationName");
    print "TM_ITERATION_NAME: $TM_ITERATION_NAME\n";

    # Set the names of the physical fields for the $ITERATIONUID_DIM_TABLE.

    $TM_ITERATION_UID = PjCLib->getPhysicalFieldDbName("TM_IterationUID_Dim", "TM_IterationUID");
    print "TM_ITERATION_UID: $TM_ITERATION_UID\n";

    # Set the names of the physical fields for the $LOGNAME_DIM_TABLE.

    $TM_LOG_NAME = PjCLib->getPhysicalFieldDbName("TM_LogName_Dim", "TM_LogName");
    print "TM_LOG_NAME: $TM_LOG_NAME\n";

    # Set the names of the physical fields for the $LOGUID_DIM_TABLE.

    $TM_LOG_UID = PjCLib->getPhysicalFieldDbName("TM_LogUID_Dim", "TM_LogUID");
    print "TM_LOG_UID: $TM_LOG_UID\n";

    # Set the names of the physical fields for the $PROJECTNAME_DIM_TABLE.

    $TM_PROJECT_NAME = PjCLib->getPhysicalFieldDbName("TM_Project_Dim", "TM_Project");
    print "TM_PROJECT_NAME: $TM_PROJECT_NAME\n";

    # Set the names of the physical fields for the $TC_RESULTS_MEASURE_TABLE.

    $BUILD_NAME = PjCLib->getPhysicalFieldDbName("TM_TCResults_Measure", "TM_BuildName_fk");
    $BUILD_UID = PjCLib->getPhysicalFieldDbName("TM_TCResults_Measure", "TM_BuildUID_fk");
    $LATEST_COLLECTION = PjCLib->getPhysicalFieldDbName("TM_TCResults_Measure", "IsLatestCollection");
    $LOG_NAME = PjCLib->getPhysicalFieldDbName("TM_TCResults_Measure", "TM_LogName_fk");
    $LOG_UID = PjCLib->getPhysicalFieldDbName("TM_TCResults_Measure", "TM_LogUID_fk");
    $PROJECT = PjCLib->getPhysicalFieldDbName("TM_TCResults_Measure", "TM_Project_fk");
    $TC_NAME = PjCLib->getPhysicalFieldDbName("TM_TCResults_Measure", "TM_TestCaseName_fk");
    $ITERATION_NAME = PjCLib->getPhysicalFieldDbName("TM_TCResults_Measure", "TM_IterationName_fk");
    $ITERATION_UID = PjCLib->getPhysicalFieldDbName("TM_TCResults_Measure", "TM_IterationUID_fk");
    $TOTAL_EXECUTED = PjCLib->getPhysicalFieldDbName("TM_TCResults_Measure", "TM_TotalExecuted");
    $TOTAL_FAILED = PjCLib->getPhysicalFieldDbName("TM_TCResults_Measure", "TM_TotalFailed");
    $TOTAL_INFORMATIONAL = PjCLib->getPhysicalFieldDbName("TM_TCResults_Measure", "TM_TotalInfo");
    $TOTAL_PASSED = PjCLib->getPhysicalFieldDbName("TM_TCResults_Measure", "TM_TotalPassed");
    $TOTAL_STOPPED = PjCLib->getPhysicalFieldDbName("TM_TCResults_Measure", "TM_TotalStopped");
    $TOTAL_TC = PjCLib->getPhysicalFieldDbName("TM_TCResults_Measure", "TM_TotalTC");
    $TOTAL_UNEVALUATED = PjCLib->getPhysicalFieldDbName("TM_TCResults_Measure", "TM_TotalUnevaluated");
    $TOTAL_WARNING = PjCLib->getPhysicalFieldDbName("TM_TCResults_Measure", "TM_TotalWarning");
    $INTERPRETED_RESULT = PjCLib->getPhysicalFieldDbName("TM_TCResults_Measure", "TM_InterpretedResult_fk");
    print "BUILD_NAME: $BUILD_NAME\n";
    print "BUILD_UID: $BUILD_UID\n";
    print "LATEST_COLLECTION = $LATEST_COLLECTION\n";
    print "LOG_NAME: $LOG_NAME\n";
    print "LOG_UID: $LOG_UID\n";
    print "PROJECT: $PROJECT\n";
    print "ITERATION_NAME: $ITERATION_NAME\n";
    print "ITERATION_UID: $ITERATION_UID\n";
    print "TC_NAME: $TC_NAME\n";
    print "TOTAL_EXECUTED: $TOTAL_EXECUTED\n";
    print "TOTAL_FAILED: $TOTAL_FAILED\n";
    print "TOTAL_INFORMATIONAL: $TOTAL_INFORMATIONAL\n";
    print "TOTAL_PASSED: $TOTAL_PASSED\n";
    print "TOTAL_STOPPED: $TOTAL_STOPPED\n";
    print "TOTAL_TC: $TOTAL_TC\n";
    print "TOTAL_UNEVALUATED: $TOTAL_UNEVALUATED\n";
    print "TOTAL_WARNING: $TOTAL_WARNING\n";
    print "INTERPRETED_RESULT: $INTERPRETED_RESULT\n";

    # Set the names of the physical fields for the $TOTALS_BY_ITERATION_TABLE.

    $LATEST_COLLECTION_FOR_ITERATION = PjCLib->getPhysicalFieldDbName("TM_TotalsByIteration_Aggregate", "IsLatestCollection");     	    
    $ITERATION_NAME_FOR_ITERATION = PjCLib->getPhysicalFieldDbName("TM_TotalsByIteration_Aggregate", "TM_IterationName_fk");
    $ITERATION_UID_FOR_ITERATION = PjCLib->getPhysicalFieldDbName("TM_TotalsByIteration_Aggregate", "TM_IterationUID_fk");
    $PROJECT_FOR_ITERATION = PjCLib->getPhysicalFieldDbName("TM_TotalsByIteration_Aggregate", "TM_Project_fk");
    $TOTAL_EXECUTED_BY_ITERATION = PjCLib->getPhysicalFieldDbName("TM_TotalsByIteration_Aggregate", "TM_ExecutedByIteration");
    $TOTAL_FAILED_BY_ITERATION = PjCLib->getPhysicalFieldDbName("TM_TotalsByIteration_Aggregate", "TM_FailedByIteration");
    $TOTAL_INFORMATIONAL_BY_ITERATION = PjCLib->getPhysicalFieldDbName("TM_TotalsByIteration_Aggregate", "TM_InfoByIteration");
    $TOTAL_PASSED_BY_ITERATION = PjCLib->getPhysicalFieldDbName("TM_TotalsByIteration_Aggregate", "TM_PassedByIteration");
    $TOTAL_STOPPED_BY_ITERATION = PjCLib->getPhysicalFieldDbName("TM_TotalsByIteration_Aggregate", "TM_StoppedByIteration");
    $TOTAL_TC_BY_ITERATION = PjCLib->getPhysicalFieldDbName("TM_TotalsByIteration_Aggregate", "TM_TCByIteration");
    $TOTAL_UNEVALUATED_BY_ITERATION = PjCLib->getPhysicalFieldDbName("TM_TotalsByIteration_Aggregate", "TM_UnevaluatedByIteration");
    $TOTAL_WARNING_BY_ITERATION = PjCLib->getPhysicalFieldDbName("TM_TotalsByIteration_Aggregate", "TM_WarningByIteration");
    print "LATEST_COLLECTION_FOR_ITERATION: $LATEST_COLLECTION_FOR_ITERATION\n";
    print "ITERATION_NAME_FOR_ITERATION: $ITERATION_NAME_FOR_ITERATION\n";
    print "ITERATION_UID_FOR_ITERATION: $ITERATION_UID_FOR_ITERATION\n";
    print "PROJECT_FOR_ITERATION: $PROJECT_FOR_ITERATION\n";
    print "TOTAL_EXECUTED_BY_ITERATION: $TOTAL_EXECUTED_BY_ITERATION\n";
    print "TOTAL_FAILED_BY_ITERATION: $TOTAL_FAILED_BY_ITERATION\n";
    print "TOTAL_INFORMATIONAL_BY_ITERATION: $TOTAL_INFORMATIONAL_BY_ITERATION\n";
    print "TOTAL_PASSED_BY_ITERATION: $TOTAL_PASSED_BY_ITERATION\n";
    print "TOTAL_STOPPED_BY_ITERATION = $TOTAL_STOPPED_BY_ITERATION\n";
    print "TOTAL_TC_BY_ITERATION: $TOTAL_TC_BY_ITERATION\n";
    print "TOTAL_UNEVALUATED_BY_ITERATION: $TOTAL_UNEVALUATED_BY_ITERATION\n";
    print "TOTAL_WARNING_BY_ITERATION: $TOTAL_WARNING_BY_ITERATION\n";


    # Set the names of the physical fields for the $TOTALS_BY_ITERATION_AND_BUILD_TABLE.

    $LATEST_COLLECTION_FOR_ITERATION_AND_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByBuildAndIteration_Aggregate", "IsLatestCollection");     	    
    $ITERATION_NAME_FOR_ITERATION_AND_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByBuildAndIteration_Aggregate", "TM_IterationName_fk");
    $ITERATION_UID_FOR_ITERATION_AND_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByBuildAndIteration_Aggregate", "TM_IterationUID_fk");
    $BUILD_NAME_FOR_ITERATION_AND_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByBuildAndIteration_Aggregate", "TM_BuildName_fk");
    $BUILD_UID_FOR_ITERATION_AND_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByBuildAndIteration_Aggregate", "TM_BuildUID_fk");
    $PROJECT_FOR_ITERATION_AND_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByBuildAndIteration_Aggregate", "TM_Project_fk");
    $TOTAL_EXECUTED_BY_ITERATION_AND_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByBuildAndIteration_Aggregate", "TM_ExecutedByBuildAndIteration");
    $TOTAL_FAILED_BY_ITERATION_AND_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByBuildAndIteration_Aggregate", "TM_FailedByBuildAndIteration");
    $TOTAL_INFORMATIONAL_BY_ITERATION_AND_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByBuildAndIteration_Aggregate", "TM_InfoByBuildAndIteration");
    $TOTAL_PASSED_BY_ITERATION_AND_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByBuildAndIteration_Aggregate", "TM_PassedByBuildAndIteration");
    $TOTAL_STOPPED_BY_ITERATION_AND_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByBuildAndIteration_Aggregate", "TM_StoppedByBuildAndIteration");
    $TOTAL_TC_BY_ITERATION_AND_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByBuildAndIteration_Aggregate", "TM_TCByBuildAndIteration");
    $TOTAL_UNEVALUATED_BY_ITERATION_AND_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByBuildAndIteration_Aggregate", "TM_UnevaluatedByBuildAndIteration");
    $TOTAL_WARNING_BY_ITERATION_AND_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByBuildAndIteration_Aggregate", "TM_WarningByBuildAndIteration");
    print "LATEST_COLLECTION_FOR_ITERATION_AND_BUILD: $LATEST_COLLECTION_FOR_ITERATION_AND_BUILD\n";
    print "ITERATION_NAME_FOR_ITERATION_AND_BUILD: $ITERATION_NAME_FOR_ITERATION_AND_BUILD\n";
    print "ITERATION_UID_FOR_ITERATION_AND_BUILD: $ITERATION_UID_FOR_ITERATION_AND_BUILD\n";
    print "BUILD_NAME_FOR_ITERATION_AND_BUILD: $BUILD_NAME_FOR_ITERATION_AND_BUILD\n";
    print "BUILD_UID_FOR_ITERATION_AND_BUILD: $BUILD_UID_FOR_ITERATION_AND_BUILD\n";
    print "PROJECT_FOR_ITERATION_AND_BUILD: $PROJECT_FOR_ITERATION_AND_BUILD\n";
    print "TOTAL_EXECUTED_BY_ITERATION_AND_BUILD: $TOTAL_EXECUTED_BY_ITERATION_AND_BUILD\n";
    print "TOTAL_FAILED_BY_ITERATION_AND_BUILD: $TOTAL_FAILED_BY_ITERATION_AND_BUILD\n";
    print "TOTAL_INFORMATIONAL_BY_ITERATION_AND_BUILD: $TOTAL_INFORMATIONAL_BY_ITERATION_AND_BUILD\n";
    print "TOTAL_PASSED_BY_ITERATION_AND_BUILD: $TOTAL_PASSED_BY_ITERATION_AND_BUILD\n";
    print "TOTAL_STOPPED_BY_ITERATION_AND_BUILD = $TOTAL_STOPPED_BY_ITERATION_AND_BUILD\n";
    print "TOTAL_TC_BY_ITERATION_AND_BUILD: $TOTAL_TC_BY_ITERATION_AND_BUILD\n";
    print "TOTAL_UNEVALUATED_BY_ITERATION_AND_BUILD: $TOTAL_UNEVALUATED_BY_ITERATION_AND_BUILD\n";
    print "TOTAL_WARNING_BY_ITERATION_AND_BUILD: $TOTAL_WARNING_BY_ITERATION_AND_BUILD\n";


    # Set the names of the physical fields for the $TOTALS_BY_BUILD_TABLE.

    $LATEST_COLLECTION_FOR_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByBuild_Aggregate", "IsLatestCollection");     	    
    $BUILD_NAME_FOR_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByBuild_Aggregate", "TM_BuildName_fk");
    $BUILD_UID_FOR_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByBuild_Aggregate", "TM_BuildUID_fk");
    $PROJECT_FOR_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByBuild_Aggregate", "TM_Project_fk");
    $TOTAL_EXECUTED_BY_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByBuild_Aggregate", "TM_ExecutedByBuild");
    $TOTAL_FAILED_BY_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByBuild_Aggregate", "TM_FailedByBuild");
    $TOTAL_INFORMATIONAL_BY_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByBuild_Aggregate", "TM_InfoByBuild");
    $TOTAL_PASSED_BY_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByBuild_Aggregate", "TM_PassedByBuild");
    $TOTAL_STOPPED_BY_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByBuild_Aggregate", "TM_StoppedByBuild");
    $TOTAL_TC_BY_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByBuild_Aggregate", "TM_TCByBuild");
    $TOTAL_UNEVALUATED_BY_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByBuild_Aggregate", "TM_UnevaluatedByBuild");
    $TOTAL_WARNING_BY_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByBuild_Aggregate", "TM_WarningByBuild");
    print "LATEST_COLLECTION_FOR_BUILD: $LATEST_COLLECTION_FOR_BUILD\n";
    print "BUILD_NAME_FOR_BUILD: $BUILD_NAME_FOR_BUILD\n";
    print "BUILD_UID_FOR_BUILD: $BUILD_UID_FOR_BUILD\n";
    print "PROJECT_FOR_BUILD: $PROJECT_FOR_BUILD\n";
    print "TOTAL_EXECUTED_BY_BUILD: $TOTAL_EXECUTED_BY_BUILD\n";
    print "TOTAL_FAILED_BY_BUILD: $TOTAL_FAILED_BY_BUILD\n";
    print "TOTAL_INFORMATIONAL_BY_BUILD: $TOTAL_INFORMATIONAL_BY_BUILD\n";
    print "TOTAL_PASSED_BY_BUILD: $TOTAL_PASSED_BY_BUILD\n";
    print "TOTAL_STOPPED_BY_BUILD = $TOTAL_STOPPED_BY_BUILD\n";
    print "TOTAL_TC_BY_BUILD: $TOTAL_TC_BY_BUILD\n";
    print "TOTAL_UNEVALUATED_BY_BUILD: $TOTAL_UNEVALUATED_BY_BUILD\n";
    print "TOTAL_WARNING_BY_BUILD: $TOTAL_WARNING_BY_BUILD\n";

    # Set the names of the physical fields for the $TOTALS_BY_LOG_AND_BUILD_TABLE.

    $LATEST_COLLECTION_FOR_LOG_AND_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByLogAndBuild_Aggregate", "IsLatestCollection");     	    
    $BUILD_NAME_FOR_LOG_AND_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByLogAndBuild_Aggregate", "TM_BuildName_fk");
    $BUILD_UID_FOR_LOG_AND_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByLogAndBuild_Aggregate", "TM_BuildUID_fk");
    $LOG_NAME_FOR_LOG_AND_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByLogAndBuild_Aggregate", "TM_LogName_fk");
    $LOG_UID_FOR_LOG_AND_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByLogAndBuild_Aggregate", "TM_LogUID_fk");
    $PROJECT_FOR_LOG_AND_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByLogAndBuild_Aggregate", "TM_Project_fk");
    $TOTAL_EXECUTED_BY_LOG_AND_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByLogAndBuild_Aggregate", "TM_ExecutedByLogAndBuild");
    $TOTAL_FAILED_BY_LOG_AND_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByLogAndBuild_Aggregate", "TM_FailedByLogAndBuild");
    $TOTAL_INFORMATIONAL_BY_LOG_AND_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByLogAndBuild_Aggregate", "TM_InfoByLogAndBuild");
    $TOTAL_PASSED_BY_LOG_AND_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByLogAndBuild_Aggregate", "TM_PassedByLogAndBuild");
    $TOTAL_STOPPED_BY_LOG_AND_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByLogAndBuild_Aggregate", "TM_StoppedByLogAndBuild");
    $TOTAL_TC_BY_LOG_AND_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByLogAndBuild_Aggregate", "TM_TCByLogAndBuild");
    $TOTAL_UNEVALUATED_BY_LOG_AND_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByLogAndBuild_Aggregate", "TM_UnevaluatedByLogAndBuild");
    $TOTAL_WARNING_BY_LOG_AND_BUILD = PjCLib->getPhysicalFieldDbName("TM_TotalsByLogAndBuild_Aggregate", "TM_WarningByLogAndBuild");
    print "LATEST_COLLECTION_FOR_LOG_AND_BUILD: $LATEST_COLLECTION_FOR_LOG_AND_BUILD\n";
    print "BUILD_NAME_FOR_LOG_AND_BUILD: $BUILD_NAME_FOR_LOG_AND_BUILD\n";
    print "BUILD_UID_FOR_LOG_AND_BUILD: $BUILD_UID_FOR_LOG_AND_BUILD\n";
    print "LOG_NAME_FOR_LOG_AND_BUILD: $LOG_NAME_FOR_LOG_AND_BUILD\n";
    print "LOG_UID_FOR_LOG_AND_BUILD: $LOG_UID_FOR_LOG_AND_BUILD\n";
    print "PROJECT_FOR_LOG_AND_BUILD: $PROJECT_FOR_LOG_AND_BUILD\n";
    print "TOTAL_EXECUTED_BY_LOG_AND_BUILD: $TOTAL_EXECUTED_BY_LOG_AND_BUILD\n";
    print "TOTAL_FAILED_BY_LOG_AND_BUILD: $TOTAL_FAILED_BY_LOG_AND_BUILD\n";
    print "TOTAL_INFORMATIONAL_BY_LOG_AND_BUILD: $TOTAL_INFORMATIONAL_BY_LOG_AND_BUILD\n";
    print "TOTAL_PASSED_BY_LOG_AND_BUILD: $TOTAL_PASSED_BY_LOG_AND_BUILD\n";
    print "TOTAL_STOPPED_BY_LOG_AND_BUILD: $TOTAL_STOPPED_BY_LOG_AND_BUILD\n";
    print "TOTAL_TC_BY_LOG_AND_BUILD: $TOTAL_TC_BY_LOG_AND_BUILD\n";
    print "TOTAL_UNEVALUATED_BY_LOG_AND_BUILD: $TOTAL_UNEVALUATED_BY_LOG_AND_BUILD\n";
    print "TOTAL_WARNING_BY_LOG_AND_BUILD: $TOTAL_WARNING_BY_LOG_AND_BUILD\n";
} # end subroutine setTableAndFieldNames



sub logon {

    #
    # Use the internal DashboardSystem login to get access to the Dashboard database
    #
    my $session = Win32::OLE->new('CLEARQUEST.SESSION');
    my $session = CQPerlExt::CQSession_Build();  
    $session->UserLogon("dashboardsystem", "dashboardsystem", "tstd1", "Dashboard");
    return $session;
}

# get date and set the global variables $currentDate and $currentTime
sub getCurrentDateTime {
    my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime(time);

    $mon = $mon + 1;
    $year = $year + 1900;

    if ($mday<10) {$mday="0$mday"; }  # add leading 0
    if ($mon<10) {$mon="0$mon"; }     # add leading 0

    # set the global variable $currentDate
    $currentDate="$year-$mon-$mday";

    # set the global variable $currentTime
    $currentTime = $hour . ":" . $min . ":" . $sec;

}

